==> haskell-wuss-2.0.1.6-23-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wuss.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wuss
version:              2.0.1.6
visibility:           public
id:                   wuss-2.0.1.6-1YU4jDyDl5DzKhlT8zjd1
key:                  wuss-2.0.1.6-1YU4jDyDl5DzKhlT8zjd1
license:              MIT
maintainer:           Taylor Fausak
synopsis:             Secure WebSocket (WSS) clients
description:
    Wuss is a library that lets you easily create secure WebSocket clients over
    the WSS protocol. It is a small addition to
    <https://hackage.haskell.org/package/websockets the websockets package> and
    is adapted from existing solutions by
    <https://gist.github.com/jaspervdj/7198388 @jaspervdj>,
    <https://gist.github.com/mpickering/f1b7ba3190a4bb5884f3 @mpickering>, and
    <https://gist.github.com/elfenlaid/7b5c28065e67e4cf0767 @elfenlaid>.

category:             Network
abi:                  26793625da6bea367c88cd19e743e0b4
exposed:              True
exposed-modules:      Wuss
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wuss-2.0.1.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wuss-2.0.1.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wuss-2.0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wuss
hs-libraries:         HSwuss-2.0.1.6-1YU4jDyDl5DzKhlT8zjd1
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    crypton-connection-0.4.5-2c10WiKFU3L73agHYaksHE exceptions-0.10.7
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    websockets-0.12.7.3-AhAyzDPktssBd5IasgBMf7

haddock-interfaces:   /usr/share/doc/haskell-wuss/html/wuss.haddock
haddock-html:         /usr/share/doc/haskell-wuss/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wuss-2.0.1.6-24-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wuss.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wuss
version:              2.0.1.6
visibility:           public
id:                   wuss-2.0.1.6-1KR5qui0UJDA9n6hGHRT1J
key:                  wuss-2.0.1.6-1KR5qui0UJDA9n6hGHRT1J
license:              MIT
maintainer:           Taylor Fausak
synopsis:             Secure WebSocket (WSS) clients
description:
    Wuss is a library that lets you easily create secure WebSocket clients over
    the WSS protocol. It is a small addition to
    <https://hackage.haskell.org/package/websockets the websockets package> and
    is adapted from existing solutions by
    <https://gist.github.com/jaspervdj/7198388 @jaspervdj>,
    <https://gist.github.com/mpickering/f1b7ba3190a4bb5884f3 @mpickering>, and
    <https://gist.github.com/elfenlaid/7b5c28065e67e4cf0767 @elfenlaid>.

category:             Network
abi:                  df8ece2494f7fb8f2a104957abf368ea
exposed:              True
exposed-modules:      Wuss
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wuss-2.0.1.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wuss-2.0.1.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wuss-2.0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wuss
hs-libraries:         HSwuss-2.0.1.6-1KR5qui0UJDA9n6hGHRT1J
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    crypton-connection-0.4.5-EMMKhGKvDZ19xloyuzywis exceptions-0.10.7
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    websockets-0.12.7.3-IxRNJzBRjoIAVwGwpWypj

haddock-interfaces:   /usr/share/doc/haskell-wuss/html/wuss.haddock
haddock-html:         /usr/share/doc/haskell-wuss/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
